pub struct Device(/* private fields */);Expand description
The Device struct encapsulates a single SYCL device on which kernels can be executed.
The Device struct provides the common reference semantics.
Implementations
Sourceimpl Device
impl Device
Sourcepub fn get_devices() -> Vec<Self>
pub fn get_devices() -> Vec<Self>
Returns a Vec containing all the root devices from all SYCL backends
available in the system which have the device type encapsulated by DeviceType.
Sourcepub fn get_info<T: DeviceInfo>(&self) -> T::Item
pub fn get_info<T: DeviceInfo>(&self) -> T::Item
Queries this Device for information requested by the generic parameter Param.
The associated type Param::Item must be defined in accordance with the info parameters
in oneapi_rs::info::device to facilitate returning the type
associated with the Param parameter.
Sourcepub fn get_platform(&self) -> Platform
pub fn get_platform(&self) -> Platform
Returns the associated SYCL platform.